*****************************
Approximations and Heuristics
*****************************

.. automodule:: networkx.algorithms.approximation


Connectivity
------------
.. automodule:: networkx.algorithms.approximation.connectivity
.. autosummary::
   :toctree: generated/

   all_pairs_node_connectivity
   local_node_connectivity
   node_connectivity


K-components
------------
.. automodule:: networkx.algorithms.approximation.kcomponents
.. autosummary::
   :toctree: generated/

   k_components


Clique
------
.. automodule:: networkx.algorithms.approximation.clique
.. autosummary::
   :toctree: generated/

   maximum_independent_set
   max_clique
   clique_removal
   large_clique_size


Clustering
----------
.. automodule:: networkx.algorithms.approximation.clustering_coefficient
.. autosummary::
   :toctree: generated/

   average_clustering


Distance Measures
-----------------
.. automodule:: networkx.algorithms.approximation.distance_measures
.. autosummary::
   :toctree: generated/

   diameter


Dominating Set
---------------
.. automodule:: networkx.algorithms.approximation.dominating_set
.. autosummary::
   :toctree: generated/

   min_weighted_dominating_set
   min_edge_dominating_set

Matching
--------
.. automodule:: networkx.algorithms.approximation.matching
.. autosummary::
   :toctree: generated/

   min_maximal_matching

Ramsey
------
.. automodule:: networkx.algorithms.approximation.ramsey
.. autosummary::
   :toctree: generated/

   ramsey_R2


Steiner Tree
------------
.. automodule:: networkx.algorithms.approximation.steinertree
.. autosummary::
   :toctree: generated/

   metric_closure
   steiner_tree


Traveling Salesman
------------------
.. automodule:: networkx.algorithms.approximation.traveling_salesman
.. autosummary::
   :toctree: generated/

   christofides
   traveling_salesman_problem
   greedy_tsp
   simulated_annealing_tsp
   threshold_accepting_tsp


Treewidth
---------
.. automodule:: networkx.algorithms.approximation.treewidth
.. autosummary::
   :toctree: generated/

   treewidth_min_degree
   treewidth_min_fill_in


Vertex Cover
------------
.. automodule:: networkx.algorithms.approximation.vertex_cover
.. autosummary::
   :toctree: generated/

   min_weighted_vertex_cover


Max Cut
-------
.. automodule:: networkx.algorithms.approximation.maxcut
.. autosummary::
   :toctree: generated/

   randomized_partitioning
   one_exchange
